# _base.scss - Base Styling

This file provides a set of base styles and normalizations for consistent rendering across different browsers and devices.

## Key Features

- Box-sizing reset
- Custom selection styling
- Base HTML and body styles
- Typography defaults
- Link styling
- Form element styling
- Custom scrollbar styling (WebKit browsers)
- Utility classes

## Notable restyled base HTML tags

- Base font size set to `62.5%` (`10px`) for easy rem calculations
- Heading styles (h1-h5) with custom line heights
- Custom styling for form `input`s, `textarea`s, and `select`s
- Floating labels
- Custom `checkbox` styling
- Responsive `figure` and `img` styling
- Custom styling for `<details>` and `<summary>` elements

### Custom Utility Classes

- `.pretty-form__item`: Wrapper for form elements
- `.input--short`: For short input fields
- `.fixed`: Applied to body to prevent scrolling
- `.wide-container`: A container with responsive padding
- `.wrapped`: For highlighted text within headings
- `.lead`: For larger, bold introductory text
- `.nodash`: Unstyled list
- `.description`: For smaller, muted text
- `.cursorPointer`: To indicate clickable elements

### Custom Scrollbar

- Customized scrollbar styling for WebKit browsers (Chrome, Safari, etc.)


# _grid.scss - a Minimalistic Bootstrap-Compatible Grid System

This grid system is a lightweight alternative to Bootstrap's grid, providing essential features for responsive design. It includes a set of SCSS mixins and classes to create flexible layouts.

## Supported Classes in _grid.scss

### Container

- **`.container`**: Creates a fixed-width container and centers it on the page.
- **`.container-fluid`**: Creates a full-width container that spans the entire width of the viewport.

### Row

- **`.row`**: Creates a flexbox container for columns, with negative margins to offset column padding.

### Columns

- **`.col-xx-#`**: Defines the width of a column for a specific breakpoint (`xx` can be `xs`, `sm`, `md`, `lg`, `xl`, `xxl`). Replace `#` with a number from 1 to 24 (based on `$grid-columns`).

### Offsets

- **`.offset-xx-#`**: Adds left margin to a column, effectively moving it to the right by the specified number of columns. Replace `xx` with the breakpoint and `#` with the number of columns to offset.

## Mixins

- `media-breakpoint-{up|down}($breakpoint)` - Applies styles at a minimum or maximum width of the specified breakpoint
- `media-breakpoint-between($lower, $upper)` - Applies styles between two breakpoints.
- `make-container($max-widths, $gutter)`
- `make-row($gutter)`
- `make-col($size, $columns)`
- `make-col-auto()`
- `make-col-offset($size, $columns)`
- `row-cols($count)`

### Justify Content
- `.justify-content-{breakpoint}-{start|end|center|between|around|evenly}`

### Order
- `.order-{breakpoint}-{first|last|0|1|2|3|4|5}`

### Display
- `.d-{breakpoint}-{none|inline|inline-block|block|table|table-row|table-cell|flex|inline-flex}`
- `.d-print-{none|inline|inline-block|block|table|table-row|table-cell|flex|inline-flex}`

`{breakpoint}` can be `xs`, `sm`, `md`, `lg`, `xl` or `xxl`.

## Customization

You can customize the grid system by modifying the variables in `_globals.scss`:

- **`$grid-columns`**: Total number of columns in the grid.
- **`$grid-gutter-width`**: Width of the gutter between columns.
- **`$grid-breakpoints`**: Map of breakpoints for responsive design.
- **`$container-max-widths`**: Maximum widths for containers at each breakpoint.
- **`$container-padding-x`**: Padding for containers.
- **`$prefix`**: Prefix for classes.
